@@ -1,5 +1,6 @@
 import os
 import sys
+import json
 import signal
 import inspect
 from flask import Flask, request, has_request_context
@@ -80,7 +81,7 @@ class asynctask(object):
 
     def exec_f(self, f, fname, args, kwargs):
         """Execute the method f asynchronously, in a mocked flask context"""
-        url = args[1] if len(args) > 1 else None
+        url = args[1] if len(args) > 1 else 'https://127.0.0.1/local'
         token = args[2] if len(args) > 2 else None
         args = args[3:] if len(args) > 3 else []
 
@@ -92,8 +93,8 @@ class asynctask(object):
         log.info(f'    url: {url}')
         log.info(f'    token: {token}')
         try:
-            log.debug('    args: {json.dumps(args, indent=4)}')
-            log.debug('    kwargs: {json.dumps(kwargs, indent=4)}')
+            log.debug(f'    args: {json.dumps(args, indent=4)}')
+            log.debug(f'    kwargs: {json.dumps(kwargs, indent=4)}')
         except TypeError:
             pass
         log.info('')
